==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DepozytPNotaOperacja.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DepozytPNotaOperacja extends GenericDPSObject {
    /**
     * DEPOZYT_P_NOTA_OPERACJA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DEPOZYT_P_NOTA_OPERACJA.DP_KONTO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dpKontoId;

    /**
     * DEPOZYT_P_NOTA_OPERACJA.DP_NOTA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dpNotaId;

    /**
     * DEPOZYT_P_NOTA_OPERACJA.M_OPERACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long mOperacjaId;

    /**
     * DEPOZYT_P_NOTA_OPERACJA.ZADLUZENIE_WYROWNANIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zadluzenieWyrownanieId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_NOTA_OPERACJA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_NOTA_OPERACJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_NOTA_OPERACJA.DP_KONTO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDpKontoId() {
        return dpKontoId;
    }

    /**
     * DEPOZYT_P_NOTA_OPERACJA.DP_KONTO_ID
     *
     * @param dpKontoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDpKontoId(Long dpKontoId) {
        this.dpKontoId = dpKontoId;
    }

    /**
     * @return DEPOZYT_P_NOTA_OPERACJA.DP_NOTA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDpNotaId() {
        return dpNotaId;
    }

    /**
     * DEPOZYT_P_NOTA_OPERACJA.DP_NOTA_ID
     *
     * @param dpNotaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDpNotaId(Long dpNotaId) {
        this.dpNotaId = dpNotaId;
    }

    /**
     * @return DEPOZYT_P_NOTA_OPERACJA.M_OPERACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getmOperacjaId() {
        return mOperacjaId;
    }

    /**
     * DEPOZYT_P_NOTA_OPERACJA.M_OPERACJA_ID
     *
     * @param mOperacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setmOperacjaId(Long mOperacjaId) {
        this.mOperacjaId = mOperacjaId;
    }

    /**
     * @return DEPOZYT_P_NOTA_OPERACJA.ZADLUZENIE_WYROWNANIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZadluzenieWyrownanieId() {
        return zadluzenieWyrownanieId;
    }

    /**
     * DEPOZYT_P_NOTA_OPERACJA.ZADLUZENIE_WYROWNANIE_ID
     *
     * @param zadluzenieWyrownanieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZadluzenieWyrownanieId(Long zadluzenieWyrownanieId) {
        this.zadluzenieWyrownanieId = zadluzenieWyrownanieId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPNotaOperacja other = (DepozytPNotaOperacja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpKontoId() == null ? other.getDpKontoId() == null : this.getDpKontoId().equals(other.getDpKontoId()))
            && (this.getDpNotaId() == null ? other.getDpNotaId() == null : this.getDpNotaId().equals(other.getDpNotaId()))
            && (this.getmOperacjaId() == null ? other.getmOperacjaId() == null : this.getmOperacjaId().equals(other.getmOperacjaId()))
            && (this.getZadluzenieWyrownanieId() == null ? other.getZadluzenieWyrownanieId() == null : this.getZadluzenieWyrownanieId().equals(other.getZadluzenieWyrownanieId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpKontoId() == null) ? 0 : getDpKontoId().hashCode());
        result = prime * result + ((getDpNotaId() == null) ? 0 : getDpNotaId().hashCode());
        result = prime * result + ((getmOperacjaId() == null) ? 0 : getmOperacjaId().hashCode());
        result = prime * result + ((getZadluzenieWyrownanieId() == null) ? 0 : getZadluzenieWyrownanieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpKontoId=").append(dpKontoId);
        sb.append(", dpNotaId=").append(dpNotaId);
        sb.append(", mOperacjaId=").append(mOperacjaId);
        sb.append(", zadluzenieWyrownanieId=").append(zadluzenieWyrownanieId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DepozytPNotaOperacja.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DepozytPNotaOperacja extends GenericDPSObject {
    /**
     * DEPOZYT_P_NOTA_OPERACJA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DEPOZYT_P_NOTA_OPERACJA.DP_KONTO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dpKontoId;

    /**
     * DEPOZYT_P_NOTA_OPERACJA.DP_NOTA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dpNotaId;

    /**
     * DEPOZYT_P_NOTA_OPERACJA.M_OPERACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long mOperacjaId;

    /**
     * DEPOZYT_P_NOTA_OPERACJA.ZADLUZENIE_WYROWNANIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zadluzenieWyrownanieId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_NOTA_OPERACJA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_NOTA_OPERACJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_NOTA_OPERACJA.DP_KONTO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDpKontoId() {
        return dpKontoId;
    }

    /**
     * DEPOZYT_P_NOTA_OPERACJA.DP_KONTO_ID
     *
     * @param dpKontoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDpKontoId(Long dpKontoId) {
        this.dpKontoId = dpKontoId;
    }

    /**
     * @return DEPOZYT_P_NOTA_OPERACJA.DP_NOTA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDpNotaId() {
        return dpNotaId;
    }

    /**
     * DEPOZYT_P_NOTA_OPERACJA.DP_NOTA_ID
     *
     * @param dpNotaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDpNotaId(Long dpNotaId) {
        this.dpNotaId = dpNotaId;
    }

    /**
     * @return DEPOZYT_P_NOTA_OPERACJA.M_OPERACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getmOperacjaId() {
        return mOperacjaId;
    }

    /**
     * DEPOZYT_P_NOTA_OPERACJA.M_OPERACJA_ID
     *
     * @param mOperacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setmOperacjaId(Long mOperacjaId) {
        this.mOperacjaId = mOperacjaId;
    }

    /**
     * @return DEPOZYT_P_NOTA_OPERACJA.ZADLUZENIE_WYROWNANIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZadluzenieWyrownanieId() {
        return zadluzenieWyrownanieId;
    }

    /**
     * DEPOZYT_P_NOTA_OPERACJA.ZADLUZENIE_WYROWNANIE_ID
     *
     * @param zadluzenieWyrownanieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZadluzenieWyrownanieId(Long zadluzenieWyrownanieId) {
        this.zadluzenieWyrownanieId = zadluzenieWyrownanieId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPNotaOperacja other = (DepozytPNotaOperacja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpKontoId() == null ? other.getDpKontoId() == null : this.getDpKontoId().equals(other.getDpKontoId()))
            && (this.getDpNotaId() == null ? other.getDpNotaId() == null : this.getDpNotaId().equals(other.getDpNotaId()))
            && (this.getmOperacjaId() == null ? other.getmOperacjaId() == null : this.getmOperacjaId().equals(other.getmOperacjaId()))
            && (this.getZadluzenieWyrownanieId() == null ? other.getZadluzenieWyrownanieId() == null : this.getZadluzenieWyrownanieId().equals(other.getZadluzenieWyrownanieId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpKontoId() == null) ? 0 : getDpKontoId().hashCode());
        result = prime * result + ((getDpNotaId() == null) ? 0 : getDpNotaId().hashCode());
        result = prime * result + ((getmOperacjaId() == null) ? 0 : getmOperacjaId().hashCode());
        result = prime * result + ((getZadluzenieWyrownanieId() == null) ? 0 : getZadluzenieWyrownanieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpKontoId=").append(dpKontoId);
        sb.append(", dpNotaId=").append(dpNotaId);
        sb.append(", mOperacjaId=").append(mOperacjaId);
        sb.append(", zadluzenieWyrownanieId=").append(zadluzenieWyrownanieId);
        sb.append("]");
        return sb.toString();
    }
}
